

.. _sphx_glr_auto_examples_datasets:

.. _dataset_examples:

Dataset examples
-----------------------

Examples concerning the :mod:`imblearn.datasets` module.



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An illustration of the make_imbalance function to create an imbalanced dataset from a balanced ...">

.. only:: html

  .. image:: /auto_examples/datasets/images/thumb/sphx_glr_plot_make_imbalance_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_datasets_plot_make_imbalance.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Create an imbalanced dataset</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/datasets/plot_make_imbalance

